==> gradientone-0.1.1.8-py2.py3-none-any.whl: gradientone/device_drivers/usb_controller.py <==
import datetime
import usbtmc
import usb.core
import usb.util
import usb.control
from gradientone import gateway_helpers


usb_logger = gateway_helpers.get_logger(log_filename='usb_controller_logs.log')

def get_timestamp():
    return str(datetime.datetime.now())

class UsbController(object):
    """Generic UsbController for talking to instruments"""
    def __init__(self, name):
        super(UsbController, self).__init__()
        self.name = name

    def get_instrument(self, mnf_id, dev_id):
        self.instr =  usbtmc.Instrument(mnf_id, dev_id)
        return self.instr

    def ask(self, instr=None, command=""):
        usb_logger.info("USB ask: %s" % command)
        if not instr:
            instr = self.instr

        response = instr.ask(command)
        return response


class RawUsbController(object):
    """Generic RawUsbController for sending usb commands"""
    def __init__(self, vendor_id=0x227f, product_id=0x0002):
        super(RawUsbController, self).__init__()
        #  instanatiates the device based off the VID/PIDs.
        self.device = usb.core.find(idVendor=vendor_id, idProduct=product_id)

    def ask(self, instr=None, command=""):
        usb_logger.info("USB ask: %s" % command)
        if not instr:
            instr = self.instr

        response = instr.ask(command)
        return response

    def write(self, ep=0x02, command='\x14\x05'):
        """the write command takes end point and the commands as arguments."""
        usb_logger.info("USB write: %s" % command)
        if not self.device:
            usb_logger.warning("missing device")
            return

        self.device.write(ep, command)

==> gradientone-0.1.3.5-py2.py3-none-any.whl: gradientone/device_drivers/usb_controller.py <==
import datetime
import usbtmc
import usb.core
import usb.util
import usb.control
from gradientone.gateway_helpers import logger


def get_timestamp():
    return str(datetime.datetime.now())


class UsbController(object):
    """Generic UsbController for talking to instruments"""
    def __init__(self, name):
        super(UsbController, self).__init__()
        self.name = name

    def get_instrument(self, mnf_id, dev_id):
        self.instr = usbtmc.Instrument(mnf_id, dev_id)
        return self.instr

    def ask(self, instr=None, command=""):
        logger.info("USB ask: %s" % command)
        if not instr:
            instr = self.instr

        response = instr.ask(command)
        return response


class RawUsbController(object):
    """Generic RawUsbController for sending usb commands"""
    def __init__(self, vendor_id=0x227f, product_id=0x0002):
        super(RawUsbController, self).__init__()
        #  instanatiates the device based off the VID/PIDs.
        self.device = usb.core.find(idVendor=vendor_id, idProduct=product_id)

    def ask(self, instr=None, command=""):
        logger.info("USB ask: %s" % command)
        if not instr:
            instr = self.instr

        response = instr.ask(command)
        return response

    def write(self, ep=0x02, command='\x14\x05'):
        """the write command takes end point and the commands as arguments."""
        logger.info("USB write: %s" % command)
        if not self.device:
            logger.warning("missing device")
            return

        self.device.write(ep, command)
